@@ -1,26 +1,28 @@
 """
-Representação de um Job do system center virtual machine manager
+System Center Virtual Machine Manager (SCVMM) job.
 """
 
 import json
 from time import sleep
+
 import tqdm
-from vmm_manager.infra.comando import Comando
-from vmm_manager.util.msgs import formatar_msg_aviso
+
+from vmm_manager.infra.command import Command
 from vmm_manager.scvmm.enums import SCJobStatusEnum
+from vmm_manager.util.msgs import formatar_msg_aviso
 
 
 class SCJob():
 
     @staticmethod
-    def monitorar_jobs(jobs, servidor_acesso):
+    def monitore_jobs(jobs, servidor_acesso):
         if jobs:
-            print('\nStatus dos processos em execução:')
+            print('\nMonitoring jobs:')
             pbars = {}
             for job in jobs.values():
                 pbar = tqdm.tqdm(total=100)
-                pbar.set_description(job.id_vmm)
-                pbars[job.id_vmm] = pbar
+                pbar.set_description(job.vmm_id)
+                pbars[job.vmm_id] = pbar
 
             # Monitorando jobs do VMM
             tem_jobs_em_andamento = len(pbars) > 0
@@ -33,17 +35,17 @@ class SCJob():
                 if not status:
                     tqdm.tqdm.write(
                         formatar_msg_aviso(
-                            '\nNão foi possível monitorar os processos em execução.\n'))
+                            '\nError while monitoring jobs.\n'))
                     break
 
                 # Atualizando status
                 for job_vmm in json.loads(jobs_vmm):
-                    id_vmm = job_vmm.get('ID')
-                    jobs[id_vmm].atualizar(job_vmm)
-                    pbars[id_vmm].update(jobs[id_vmm].ultimo_progresso)
-                    pbars[id_vmm].refresh()
+                    vmm_id = job_vmm.get('ID')
+                    jobs[vmm_id].atualizar(job_vmm)
+                    pbars[vmm_id].update(jobs[vmm_id].ultimo_progresso)
+                    pbars[vmm_id].refresh()
 
-                    if not jobs[id_vmm].is_finalizado:
+                    if not jobs[vmm_id].is_finalizado:
                         tem_jobs_em_andamento = True
 
                 # Aguardando um tempo para próxima checagem
@@ -56,16 +58,16 @@ class SCJob():
 
     @staticmethod
     def __obter_status_jobs_vmm(jobs, servidor_acesso):
-        cmd = Comando('monitorar_jobs',
-                      servidor_vmm=servidor_acesso.servidor_vmm,
+        cmd = Command('monitore_jobs',
+                      vmm_server=servidor_acesso.vmm_server,
                       jobs=jobs)
         return cmd.executar(servidor_acesso)
 
-    def __init__(self, id_vmm, acao):
-        self.id_vmm = id_vmm
+    def __init__(self, vmm_id, acao):
+        self.vmm_id = vmm_id
         self.acao = acao
 
-        self.nome = None
+        self.name = None
         self.status = None
         self.is_finalizado = None
         self.resumo_erro = None
@@ -90,7 +92,7 @@ class SCJob():
                 not self.is_finalizado_com_erro())
 
     def atualizar(self, job_vmm):
-        self.nome = job_vmm.get('Name')
+        self.name = job_vmm.get('Name')
         self.status = SCJobStatusEnum(job_vmm.get('Status'))
         self.is_finalizado = job_vmm.get('IsCompleted')
 
@@ -111,9 +113,9 @@ class SCJob():
 
     def __str__(self):
         return f'''
-            id_vmm: {self.id_vmm}
+            vmm_id: {self.vmm_id}
             acao: {self.acao}
-            nome: {self.nome}
+            name: {self.name}
             status: {self.status}
             is_finalizado: {self.is_finalizado}
             progresso: {self.progresso}
